@@ -65,7 +65,7 @@ class CompilationError < RuntimeError; end
 # the current namespace.
 
 module Inline
-  VERSION = "3.12.2"
+  VERSION = "3.12.4"
 
   WINDOZE  = /mswin|mingw/ =~ RUBY_PLATFORM
   RUBINIUS = defined? RUBY_ENGINE
@@ -566,7 +566,9 @@ VALUE #{method}_equals(VALUE value) {
           flags = @flags.join(' ')
           libs  = @libs.join(' ')
 
-          config_hdrdir = if RUBY_VERSION > '1.9' then
+          config_hdrdir = if RbConfig::CONFIG['rubyarchhdrdir'] then
+                            "-I #{RbConfig::CONFIG['rubyarchhdrdir']}"
+                          elsif RUBY_VERSION > '1.9' then
                             "-I #{File.join hdrdir, RbConfig::CONFIG['arch']}"
                           else
                             nil
@@ -592,12 +594,12 @@ VALUE #{method}_equals(VALUE value) {
                   (RbConfig::CONFIG['CCDLFLAGS']        if windoze),
                 ].compact.join(' ')
 
-         # strip off some makefile macros for mingw 1.9
-         cmd = cmd.gsub(/\$\(.*\)/, '') if RUBY_PLATFORM =~ /mingw/
+          # odd compilation error on clang + freebsd 10. Ruby built w/ rbenv.
+          cmd = cmd.gsub(/-Wl,-soname,\$@/, "-Wl,-soname,#{File.basename so_name}")
+
+          # strip off some makefile macros for mingw 1.9
+          cmd = cmd.gsub(/\$\(.*\)/, '') if RUBY_PLATFORM =~ /mingw/
 
-          # TODO: remove after osx 10.5.2
-          cmd += ' -flat_namespace -undefined suppress' if
-            RUBY_PLATFORM =~ /darwin9\.[01]/
           cmd += " 2> #{DEV_NULL}" if $TESTING and not $DEBUG
 
           warn "Building #{so_name} with '#{cmd}'" if $DEBUG
